==> lms-1.5.0.tar.gz: lms/modules/rtqueueedit.php <==
<?php

/*
 * LMS version 1.5.0 Marduk
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueueedit.php,v 1.2 2004/09/18 19:21:28 alec Exp $
 */

if(! $LMS->QueueExists($_GET['id']))
{
	header('Location: ?m=rtqueuelist');
	die;
}

$queue = $_POST['queue'];

if(isset($queue))
{
	$queue['id'] = $_GET['id'];
	
	if($queue['name'] == '')
		$error['name'] = "Kolejka musi posiada nazw!";

	if($queue['email']!='' && !check_email($queue['email']))
		$error['email'] = 'Podany email nie wydaje si by poprawny!';

	if(isset($queue['admins']))
		foreach($queue['admins'] as $key => $value)
			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['adminnames'][$key]);

	if(!$error)
	{
		$LMS->QueueUpdate($queue);
		header("Location: ?m=rtqueueinfo&id=".$queue['id']);
		die;
	}
}
else
	$queue = $LMS->GetQueue($_GET['id']);

$layout['pagetitle'] = 'Edycja kolejki: '.$queue['name'];

$_SESSION['backto'] = $_SERVER['QUERY_STRING'];

$SMARTY->assign('queue', $queue);
$SMARTY->assign('error', $error);
$SMARTY->display('rtqueueedit.html');

?>

==> lms-1.8.0rc5.tar.gz: lms/modules/rtqueueedit.php <==
<?php

/*
 * LMS version 1.8.0rc5 Rosha
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: rtqueueedit.php,v 1.9.2.1 2005/12/07 08:56:21 alec Exp $
 */

if(! $LMS->QueueExists($_GET['id']))
{
	$SESSION->redirect('?m=rtqueuelist');
}

$queue = $_POST['queue'];

if(isset($queue))
{
	$queue['id'] = $_GET['id'];
	
	if($queue['name'] == '')
		$error['name'] = trans('Queue name must be defined!');

	if($queue['email']!='' && !check_email($queue['email']))
		$error['email'] = trans('Incorrect email!');

	if(isset($queue['users']))
		foreach($queue['users'] as $key => $value)
			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['usernames'][$key]);

	if(!$error)
	{
		$LMS->QueueUpdate($queue);
		$SESSION->redirect('?m=rtqueueinfo&id='.$queue['id']);
	}
}
else
	$queue = $LMS->GetQueue($_GET['id']);

$layout['pagetitle'] = trans('Queue Edit: $0',$queue['name']);

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$SMARTY->assign('queue', $queue);
$SMARTY->assign('error', $error);
$SMARTY->display('rtqueueedit.html');

?>
